==> mozc-1.3.931.102.tar.bz2: mozc-1.3.931.102/gui/update_dialog/update_dialog.h <==
// Copyright 2010-2011, Google Inc.
// All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are
// met:
//
//     * Redistributions of source code must retain the above copyright
// notice, this list of conditions and the following disclaimer.
//     * Redistributions in binary form must reproduce the above
// copyright notice, this list of conditions and the following disclaimer
// in the documentation and/or other materials provided with the
// distribution.
//     * Neither the name of Google Inc. nor the names of its
// contributors may be used to endorse or promote products derived from
// this software without specific prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
// "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
// LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
// A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
// OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
// SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
// LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
// DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
// THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

#ifndef MOZC_GUI_UPDATE_DIALOG_H_
#define MOZC_GUI_UPDATE_DIALOG_H_

#include <QtCore/QString>
#include <QtGui/QtGui>
#include <QtGui/QDialog>
#include "base/base.h"
#include "gui/update_dialog/ui_update_dialog.h"

#if defined(OS_WINDOWS) && defined(GOOGLE_JAPANESE_INPUT_BUILD)
#define USE_UPDATE_CHECKER
#endif  // OS_WINDOWS && GOOGLE_JAPANESE_INPUT_BUILD

namespace mozc {

namespace gui {
class UpdateDialog : public QDialog,
                     private Ui::UpdateDialog {
  Q_OBJECT;

 public:
  UpdateDialog();
  virtual ~UpdateDialog();

 protected:
#ifdef USE_UPDATE_CHECKER
  bool winEvent(MSG *message, long *result);
#endif  // USE_UPDATE_CHECKER

 private:
  bool new_version_found_;
};
}  // namespace mozc::gui
}  // namespace mozc
#endif  // MOZC_GUI_UPDATE_DIALOG_H_

==> mozc-1.10.1390.102.tar.bz2: mozc-1.10.1390.102/gui/update_dialog/update_dialog.h <==
// Copyright 2010-2013, Google Inc.
// All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are
// met:
//
//     * Redistributions of source code must retain the above copyright
// notice, this list of conditions and the following disclaimer.
//     * Redistributions in binary form must reproduce the above
// copyright notice, this list of conditions and the following disclaimer
// in the documentation and/or other materials provided with the
// distribution.
//     * Neither the name of Google Inc. nor the names of its
// contributors may be used to endorse or promote products derived from
// this software without specific prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
// "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
// LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
// A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
// OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
// SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
// LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
// DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
// THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

#ifndef MOZC_GUI_UPDATE_DIALOG_H_
#define MOZC_GUI_UPDATE_DIALOG_H_

#include <QtCore/QString>
#include <QtGui/QtGui>
#include <QtGui/QDialog>
#include "base/base.h"
#include "gui/update_dialog/ui_update_dialog.h"

#if defined(OS_WIN) && defined(GOOGLE_JAPANESE_INPUT_BUILD)
#define USE_UPDATE_CHECKER
#endif  // OS_WIN && GOOGLE_JAPANESE_INPUT_BUILD

namespace mozc {

namespace gui {
class UpdateDialog : public QDialog,
                     private Ui::UpdateDialog {
  Q_OBJECT;

 public:
  UpdateDialog();
  virtual ~UpdateDialog();

 protected:
#ifdef USE_UPDATE_CHECKER
  bool winEvent(MSG *message, long *result);
#endif  // USE_UPDATE_CHECKER

 private:
  bool new_version_found_;
};
}  // namespace mozc::gui
}  // namespace mozc
#endif  // MOZC_GUI_UPDATE_DIALOG_H_
